@@ -16,7 +16,7 @@
 #
 
 from ai.h2o.sparkling.ml.algos import H2OKMeans, H2OAutoML, H2OGridSearch, H2OGLM, H2OGBM, H2OXGBoost, H2ODeepLearning
-from ai.h2o.sparkling.ml.algos import H2ODRF, H2OGAM, H2OIsolationForest, H2OCoxPH
+from ai.h2o.sparkling.ml.algos import H2ODRF, H2OGAM, H2OIsolationForest, H2OCoxPH, H2ORuleFit, H2OStackedEnsemble
 
 __all__ = ["H2OAutoML", "H2OGridSearch", "H2OGLM", "H2OGAM", "H2OGBM", "H2OXGBoost", "H2ODeepLearning", "H2OKMeans",
-           "H2ODRF", "H2OIsolationForest", "H2OCoxPH"]
+           "H2ODRF", "H2OIsolationForest", "H2OCoxPH", "H2ORuleFit", "H2OStackedEnsemble"]
